@@ -1,10 +1,31 @@
 package Logger::Fq;
 
+# Copyright (c) 2015, Circonus, Inc.
+# All rights reserved.
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to
+# deal in the Software without restriction, including without limitation the
+# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+# sell copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+# IN THE SOFTWARE.
+
 require DynaLoader;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = "0.2.10";
+$VERSION = "0.2.11";
 @ISA = qw/DynaLoader/;
 
 bootstrap Logger::Fq $VERSION ;
@@ -15,13 +36,13 @@ Logger::Fq - Log asynchronously to an Fq instance.
 
 =head1 SYNOPSIS
 
-	use Logger::Fq;
+  use Logger::Fq;
   Logger::Fq::enable_drain_on_exit(1);
 
-	my $logger = Logger::Fq->new( host => '127.0.0.1', port => 8765,
-                                exchange => 'logging );
+  my $logger = Logger::Fq->new({ host => '127.0.0.1', port => 8765,
+                                exchange => 'logging });
   $logger->log("protocol.category", "Message");
-	
+
 =head1 DESCRIPTION
 
 C<Logger::Fq> provides an asynchronous method of logging information via Fq.
@@ -32,18 +53,18 @@ never block perl (assuming an IP address is used).
 
 =over 4
 
-=item new()
+=item new($options)
 
 Creates a new Logger::Fq object.
 
-     (
+     {
        user => $user,           #default 'guest'
        password => $password,   #default 'guest'
        port => $port,           #default 8765
        host => $vhost,          #default '127.0.0.1'
-			 exchange => $exchange,   #default 'logging'
+       exchange => $exchange,   #default 'logging'
        heartbeat => $hearbeat,  #default 1000 (ms)
-     )
+     }
 
 =item log( $channel, $message )
 
@@ -69,6 +90,10 @@ This will cause Logger::Fq to register an END {} function that will wait up to
 $s seconds (microsecond resolution) to drain backlogged messages. If $verbose
 is specified, print to STDERR the number of messages drain and the time waited.
 
+=item Logger::Fq::debug($flags)
+
+Sets the fileno=2 debugging bits for libfq.
+
 =cut
 
 our ($should_wait_on_exit, $should_be_verbose_on_exit);
